@@ -8,9 +8,10 @@ class Address(object):
     The class to represent the RPC address.
     """
 
-    def __init__(self, host, port):
+    def __init__(self, host, port, family=socket.AF_UNSPEC):
         self._host = host
         self._port = port
+        self._family = family
 
     @property
     def host(self):
@@ -23,8 +24,8 @@ class Address(object):
     def unpack(self):
         return (self._host, self._port)
 
-    def socket(self, family=socket.AF_UNSPEC):
-        res = socket.getaddrinfo(self._host, self._port, family,
+    def socket(self):
+        res = socket.getaddrinfo(self._host, self._port, self._family,
                                  socket.SOCK_STREAM, 0, socket.AI_PASSIVE)[0]
         af, socktype, proto, canonname, sockaddr = res
         sock = socket.socket(af, socktype, proto)
