@@ -7,10 +7,11 @@ class Loop(object):
 
     @staticmethod
     def instance():
-        return Loop(ioloop.IOLoop.instance())
+        return Loop(ioloop.IOLoop.current())
 
     def __init__(self, loop=None):
         self._ioloop = loop or ioloop.IOLoop()
+        self._ioloop.make_current()
         self._periodic_callback = None
 
     def start(self):
@@ -18,19 +19,17 @@ class Loop(object):
         Starts the Tornado's ioloop if it's not running.
         """
 
-        if not self._ioloop.running():
-            self._ioloop.start()
+        self._ioloop.start()
 
     def stop(self):
         """\
         Stops the Tornado's ioloop if it's running.
         """
 
-        if self._ioloop.running():
-            try:
-                self._ioloop.stop()
-            except:
-                return
+        try:
+            self._ioloop.stop()
+        except:
+            return
 
     def attach_periodic_callback(self, callback, callback_time):
         if self._periodic_callback is not None:
