@@ -1,11 +1,9 @@
-import msgpack
-
 from msgpackrpc import Loop
 from msgpackrpc import message
-from msgpackrpc.error import RPCError
 from msgpackrpc.future import Future
 from msgpackrpc.transport import tcp
 from msgpackrpc.compat import iteritems
+from msgpackrpc.error import TimeoutError
 
 
 class Session(object):
@@ -97,7 +95,7 @@ class Session(object):
         self._loop.stop()
 
     def on_timeout(self, msgid):
-        future = self._request_table.pop(timeout)
+        future = self._request_table.pop(msgid)
         future.set_error("Request timed out")
 
     def step_timeout(self):
@@ -112,7 +110,7 @@ class Session(object):
         self._loop.stop()
         for timeout in timeouts:
             future = self._request_table.pop(timeout)
-            future.set_error("Request timed out")
+            future.set_error(TimeoutError("Request timed out"))
         self._loop.start()
 
 
